@@ -2145,15 +2145,20 @@ GVApi::callBack(AsyncTaskToken *token)
     QString strContent, strTemp;
     QUrl url(GV_HTTPS "/call/connect");
 
-    strContent = QString("outgoingNumber=%1&forwardingNumber=%2&phoneType=%3")
-                    .arg (token->inParams["destination"].toString())
-                    .arg (token->inParams["source"].toString())
-                    .arg (token->inParams["sourceType"].toString());
+    QUrl urlContent(GV_HTTPS "/call/connect");
+    QVariantMap m;
+    int zero = 0;
+    m["outgoingNumber"]   = token->inParams["destination"].toString();
+    m["forwardingNumber"] = token->inParams["source"].toString();
+    m["phoneType"]        = token->inParams["sourceType"].toString();
+    m["subscriberNumber"] = token->inParams["strSelfNumber"].toString();
+    m["remember"]         = zero;
+    m["_rnr_se"]          = rnr_se;
 
-    strContent += QString("&subscriberNumber=%1&remember=1&_rnr_se=%2")
-                    .arg (strSelfNumber, rnr_se);
+    NwHelpers::appendQueryItems (urlContent, m);
+    strContent = NwHelpers::fullyEncodedQuery (urlContent);
 
-    Q_DEBUG(QString("Call back request = %1").arg(strContent));
+    Q_DEBUG(QString("Call back request content = %1").arg(strContent));
 
     bool rv =
     doPostForm(url, strContent.toLatin1 (), token, this,
@@ -2190,12 +2195,25 @@ GVApi::onCallback(bool success, const QByteArray &response, QNetworkReply *,
         strTemp = QString("var obj = %1; obj.ok;").arg(strTemp);
         strTemp = scriptEngine.evaluate (strTemp).toString ();
         if (scriptEngine.hasUncaughtException ()) {
-            Q_WARN("Failed to parse call out response: ") << strReply;
+            Q_WARN("Failed to parse call back response: ") << strReply;
             Q_WARN("Error is: ") << strTemp;
             break;
         }
 
         if (strTemp != "true") {
+            quint32 code = scriptEngine.evaluate ("obj.data.code").toInt32 ();
+            if (scriptEngine.hasUncaughtException ()) {
+                Q_WARN("Failed to parse call back code: ") << strReply;
+                break;
+            }
+
+            if (1 == code) {
+                Q_WARN("Cannot start a new dial back call while there is one "
+                       "in progress.");
+                token->status = ATTS_IN_PROGRESS;
+                break;
+            }
+
             Q_WARN(QString("Failed to call back! response ok=%1. response='%2'")
                    .arg(strTemp).arg(QString(response)));
             break;
@@ -2218,6 +2236,103 @@ GVApi::onCallback(bool success, const QByteArray &response, QNetworkReply *,
     }
 }//GVApi::onCallback
 
+bool
+GVApi::cancelDialBack(AsyncTaskToken *token)
+{
+    Q_ASSERT(token);
+    if (!token) {
+        return false;
+    }
+
+    if (!loggedIn) {
+        token->status = ATTS_NOT_LOGGED_IN;
+        token->emitCompleted ();
+        return true;
+    }
+
+    if (rnr_se.isEmpty ()) {
+        token->status = ATTS_AC_NOT_CONFIGURED;
+        token->emitCompleted ();
+        return true;
+    }
+
+    QUrl url(GV_HTTPS "/call/cancel");
+    QUrl urlContent(GV_HTTPS "/call/cancel");
+    QVariantMap m;
+    m["outgoingNumber"]   = "";
+    m["forwardingNumber"] = "";
+    m["cancelType"]       = "C2C";
+    m["_rnr_se"]          = rnr_se;
+
+    NwHelpers::appendQueryItems (urlContent, m);
+    QString strContent = NwHelpers::fullyEncodedQuery (urlContent);
+
+    Q_DEBUG(QString("Call back request content = %1").arg(strContent));
+
+    bool rv =
+    doPostForm(url, strContent.toLatin1 (), token, this,
+               SLOT(onCallback(bool,const QByteArray&,QNetworkReply*,void*)));
+    Q_ASSERT(rv);
+
+    return (rv);
+}//GVApi::cancelDialBack
+
+void
+GVApi::onCancelDialBack(bool success, const QByteArray &response,
+                        QNetworkReply *reply, void *ctx)
+{
+    AsyncTaskToken *token = (AsyncTaskToken *)ctx;
+    QString strReply = response;
+
+    do {
+        if (!success) {
+            Q_WARN("Failed to cancel dial back");
+            token->status = ATTS_NW_ERROR;
+            break;
+        }
+        success = false;
+
+#if 0
+        Q_DEBUG(strReply);
+#endif
+
+        QString strTemp = strReply.mid (strReply.indexOf (",\n"));
+        if (strTemp.startsWith (',')) {
+            strTemp = strTemp.mid (strTemp.indexOf ('{'));
+        }
+
+        strTemp = QString("var obj = %1; obj.ok;").arg(strTemp);
+        strTemp = scriptEngine.evaluate (strTemp).toString ();
+        if (scriptEngine.hasUncaughtException ()) {
+            Q_WARN("Failed to parse cancel dial back response: ") << strReply;
+            Q_WARN("Error is: ") << strTemp;
+            break;
+        }
+
+        if (strTemp != "true") {
+            Q_WARN(QString("Failed to cancel dial back! response ok=%1. "
+                           "response='%2'")
+                   .arg(strTemp).arg(QString(response)));
+            break;
+        }
+
+        token->status = ATTS_SUCCESS;
+        token->emitCompleted ();
+        token = NULL;
+
+        success = true;
+    } while (0);
+
+    if (!success) {
+        if (token) {
+            if (token->status == ATTS_SUCCESS) {
+                token->status = ATTS_FAILURE;
+            }
+            token->emitCompleted ();
+        }
+    }
+}//GVApi::onCancelDialBack
+
 bool
 GVApi::sendSms(AsyncTaskToken *token)
 {
@@ -2249,7 +2364,7 @@ GVApi::sendSms(AsyncTaskToken *token)
     m["v"]   = "13";
     m["txt"] = token->inParams["text"].toString();
     NwHelpers::appendQueryItems (url, m);
-    url = QUrl(NwHelpers::fullyEncodedString (url));
+    url = QUrl(NwHelpers::fullyEncodedUrl (url));
 
     return doSendSms (url, token);
 }//GVApi::sendSms
