@@ -46,7 +46,10 @@ public:
     void setMandatoryLocalPicsFlag(bool value);
     bool getMandatoryLocalPicsFlag();
 
-    bool login(const QString &user, const QString &pass);
+    void init();
+
+    bool login(const QString &user);
+    void logout();
 
     bool getContactInfoFromLink(ContactInfo &cinfo);
     bool getContactInfoFromNumber(QString num, ContactInfo &cinfo);
@@ -65,8 +68,12 @@ public slots:
 protected:
     ContactsModel *createModel(const QString &query = QString());
     void startNextPhoto();
+    bool getOnePhoto(QString contactId, QString photoUrl);
 
 protected slots:
+    void onOpenBrowser(const QUrl &url);
+    void onCloseBrowser();
+
     void loginCompleted();
     void onPresentCaptcha(AsyncTaskToken *task, const QString &captchaUrl);
     void onOneContact(ContactInfo cinfo);
@@ -83,6 +90,7 @@ protected:
     bool        m_enableTimerUpdate;
 
     PhotoLinkList m_noPhotos;
+    bool        m_isDownloadingPhoto;
 
 public:
     ContactsModel       *m_contactsModel;
